@@ -60,10 +60,12 @@ class StringExpandShrink:
 class StructureExpandShrink:
 
     async def expand(self, value, transpile=True):
+        if value is None: return None
         structure = get_packer_registry().get_structure(self.identifier)
         return await structure.expand(value)
 
     async def shrink(self, instance,**kwargs):
+        if not instance: return None
         if isinstance(instance, Structure) or hasattr(instance, "shrink"): return await instance.shrink()
         # Instance we are trying to shrink needs to be transpile to the required model
         from arkitekt.packers.transpilers.registry import get_transpiler_registry
